#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys
import os
from os.path import join, dirname, exists
import argparse

def main(arguments=None):
    if arguments is None:
        arguments = sys.argv[1:]

    lines = []
    if not sys.stdin.isatty():
        lines = [line.strip() for line in sys.stdin]

    parser = argparse.ArgumentParser(description='Renames a folder or file.', prog="ren")
    parser.add_argument('path', help='the source path to rename', nargs='*')
    parser.add_argument('name', help='the name of the file', nargs=1)

    options = parser.parse_args(arguments)
    name = options.name[0]

    if lines:
        for line in lines:
            move(line, name)
    else:
        from_path = options.path[0]
        move(from_path, name)

def move(from_path, name):
    to_path = join(dirname(from_path), name)

    if exists(to_path):
        print "%s already exists - skipping..." % to_path
    else:
        os.rename(from_path, to_path)
        print "renamed %s to %s" % (from_path, to_path)

if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/python
# -*- coding: utf-8 -*-

# ren command
# https://github.com/heynemann/ren

# Licensed under the MIT license: 
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2012 Bernardo Heynemann heynemann@gmail.com

from setuptools import setup, Extension
from ren.version import __version__

def run_setup():
  setup(
      name = 'ren',
      version = __version__,
      description = "ren is a command for easily renaming directories and files.",
      long_description = """
ren is a command for easily renaming directories and files.

Usage:

    ren /tmp/some/folder dir
    # renames /tmp/some/folder to /tmp/some/dir

""",
      keywords = 'filesystem bash rename mv move',
      author = 'Bernardo Heynemann',
      author_email = 'heynemann@gmail.com',
      url = 'https://github.com/heynemann/ren',
      license = 'MIT',
      classifiers = ['Development Status :: 4 - Beta',
                     'Intended Audience :: Developers',
                     'License :: OSI Approved :: MIT License',
                     'Natural Language :: English',
                     'Operating System :: MacOS',
                     'Operating System :: POSIX :: Linux',
                     'Programming Language :: Python :: 2.6',
      ],
      packages = ['ren'],
      package_dir = {"ren": "ren"},

      install_requires=[
          'argparse'
      ],

      entry_points = {
          'console_scripts': [
              'ren = ren.ren:main',
          ],
      },
  )

run_setup()
